Este cenário prevê que **{mortality}** por 100.000 habitantes morreria no surto
de COVID-19. Este número corresponde a **{fatality}** de todos que ficaram doentes.
O modelo também indica que **{infected}** da população será infectada pelo vírus, mas apenas
**{symptomatic}** destes desenvolverão sintomas visíveis.

**IMPORTANTE:** Modelos são simplificações da realidade e dependem fortemente de
bons valores para os parâmetros baseados em dados. Ainda existem vários aspectos epidemiológicos
da COVID-19 que permanecem em aberto no debate científico e cientistas ainda estão tentando determinar
valores mais precisos para vários parâmetros importantes. As escolhas feitas aqui são baseadas no
conhecimento científico atual sobre a epidemia, mas ainda são bastante incertas. No entanto, escolher valores
absurdos para os parâmetros certamente criará previsões absurdas. Dito isso, use a calculadora com cuidado!

O desenrolar da epidemia também depende crucialmente de como as comunidades reagem. Isto é
codificado de maneira muito simplista nos comandos de "Opções de Intervenção" do simulador. Nós
não tentamos antecipar como estas comunidades irão responder à epidemia, mas apenas damos a opção
de traçar diferentes cenários de resposta. Por isso, dizemos que esta caluladora produz apenas cenários
e não previsões sobre o futuro.
